@@ -1,5 +1,5 @@
 package Moose::Exception::Role::Role;
-our $VERSION = '2.1500'; # TRIAL
+our $VERSION = '2.1501'; # TRIAL
 
 # use Moose::Util 'throw_exception';
 use Moose::Role;
@@ -8,7 +8,7 @@ has 'role_name' => (
     is            => 'ro',
     isa           => 'Str',
     required      => 1,
-    documentation => "This attribute can be used for fetching metaclass instance:\n".
+    documentation => "This attribute can be used for fetching the class's metaclass instance:\n".
                      "    my \$metaclass_instance = Moose::Util::find_meta( \$exception->role_name );\n",
 
 );
