@@ -1,5 +1,5 @@
 package Moose::Meta::Class;
-our $VERSION = '2.1500'; # TRIAL
+our $VERSION = '2.1501'; # TRIAL
 
 use strict;
 use warnings;
@@ -228,35 +228,6 @@ sub calculate_all_roles_with_inheritance {
              $self->linearized_isa;
 }
 
-sub does_via_delegation {
-    my ($self, $role_name, $instance) = @_;
-
-    return 0 if not blessed($instance);
-
-    (defined $role_name)
-        || throw_exception( RoleNameRequired => class_name => $self->name );
-
-    # liberally borrowed from TOBYINK's MooseX::Does::Delegated
-    for my $attr ($self->get_all_attributes) {
-        # Skip things unless we're actually delegating
-        next unless $attr->can('handles') && $attr->can('has_handles') && $attr->has_handles;
-
-        # uninitialized/non-lazy attributes have no value to be delegated to
-        next unless $attr->has_value($instance) || $attr->is_lazy;
-
-        # Now delegation comes in several forms but they basically boil down to references
-        # and non-references (i.e. Class and Role names). We only care about the latter.
-        # If the role name matches exactly, or if it's something that does the
-        # role in question ... we're good
-        my $handles = $attr->handles;
-        next if ref $handles;
-        return 1 if $role_name eq $handles;
-        return 1 if Class::MOP::class_of($handles)->does_role($role_name);
-    }
-
-    return 0;
-}
-
 sub does_role {
     my ($self, $role_name) = @_;
 
@@ -831,7 +802,7 @@ Moose::Meta::Class - The Moose metaclass
 
 =head1 VERSION
 
-version 2.1500
+version 2.1501
 
 =head1 DESCRIPTION
 
@@ -944,12 +915,6 @@ adds it to the class's list of role applications. This I<does not>
 actually apply any role to the class; it is only for tracking role
 applications.
 
-=item B<< $metaclass->does_via_delegation($role, $object_instance) >>
-
-This returns a boolean indicating whether or not the class does the specified
-role via a delegated attribute. The role provided can be either a role name or
-a L<Moose::Meta::Role> object. This tests both delegation to roles and classes.
-
 =item B<< $metaclass->does_role($role) >>
 
 This returns a boolean indicating whether or not the class does the specified
